==> haskell-skylighting-format-blaze-html-0.1.1.3-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-blaze-html
version:              0.1.1.3
visibility:           public
id:
    skylighting-format-blaze-html-0.1.1.3-IFFOiuIv3R2FPqJyT1PiVc

key:
    skylighting-format-blaze-html-0.1.1.3-IFFOiuIv3R2FPqJyT1PiVc

license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             HTML formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as HTML.

category:             Text
abi:                  94efc38e10e8b11635e327a543e2b8bc
exposed:              True
exposed-modules:      Skylighting.Format.HTML
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-blaze-html
hs-libraries:
    HSskylighting-format-blaze-html-0.1.1.3-IFFOiuIv3R2FPqJyT1PiVc

depends:
    base-4.17.2.1 blaze-html-0.9.2.0-4j6jevlp0QUEusbPG23DSX
    containers-0.6.7 skylighting-core-0.14.1.1-Cp1QotiwbnFCtvf6AOnbds
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-blaze-html/html/skylighting-format-blaze-html.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-blaze-html/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-blaze-html-0.1.1.3-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-blaze-html
version:              0.1.1.3
visibility:           public
id:
    skylighting-format-blaze-html-0.1.1.3-5fkc7YOA77pGp08MiWqqGW

key:
    skylighting-format-blaze-html-0.1.1.3-5fkc7YOA77pGp08MiWqqGW

license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             HTML formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as HTML.

category:             Text
abi:                  f95692e3038ff89a5e5c55ce734b3f97
exposed:              True
exposed-modules:      Skylighting.Format.HTML
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-blaze-html
hs-libraries:
    HSskylighting-format-blaze-html-0.1.1.3-5fkc7YOA77pGp08MiWqqGW

depends:
    base-4.17.2.1 blaze-html-0.9.2.0-4j6jevlp0QUEusbPG23DSX
    containers-0.6.7 skylighting-core-0.14.1.1-Kxl4scGMUrDBiO5POnlt4W
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-blaze-html/html/skylighting-format-blaze-html.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-blaze-html/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
